
version 8           // tell Stata which version program was created in
clear
set memory 800m

capture log close
log using kmt.log, replace                       


*****************************************************************************************************
//     This file reads data and does various regressions
//     for EM&S paper
*****************************************************************************************************


//                  Read in data
clear
insheet using pollution.and.weather.csv
	drop if datecode<27030        // drop pre-1974
	drop if datecode>34394		// drop post March 1994
	drop if city=="Toronto2"	// inner and outer aggregated, drop separate outer
	drop if city=="Montreal2"
	drop if city=="Vancouver2"
	capture save "pw.dta", replace
	clear

insheet using SocioEcon.csv
	generate provrate=(avgearn/avgearn[_n-1]-1) 		//  growth factor of avg earnings, will apply after Jan 1983
	drop if datecode<27030        // drop pre-1974
	drop if datecode>34394		// drop post March 1994
	drop if city=="Toronto2"
	drop if city=="Montreal2"
	drop if city=="Vancouver2"
	capture save "se.dta", replace
	clear

insheet using admits.csv
	drop if datecode<27030        // drop pre-1974
	drop if datecode>34394		// drop post March 1994
	drop if city=="Toronto2"
	drop if city=="Montreal2"
	drop if city=="Vancouver2"
	capture save "al.dta", replace
	clear

insheet using provpop.csv
	drop if datecode<27030        // drop pre-1974
	drop if datecode>34394		// drop post March 1994
	drop if city=="Toronto2"
	drop if city=="Montreal2"
	drop if city=="Vancouver2"
	keep provpop
	capture save "p.dta", replace
	clear


use pw.dta
	merge using se.dta
	drop _merge
	capture save "pwse.dta", replace
	clear

use pwse.dta
	merge using al.dta
	drop _merge
	drop montreal2 vancouver2
	capture save "pwseal.dta" , replace
	clear

use pwseal.dta
	merge using p.dta
	drop _merge
	describe
	capture save "pwsealp.dta" , replace

sum

*******************************************************************************
*
*		Fix post-1982 splice
*
*******************************************************************************

	sum avgearn
	replace provrate=0 if datecode==30317		//  growth rate assumed =0 in Jan 1983, removes splice effect

	generate incseries=avgearn
	replace incseries=incseries[_n-1]*(1+provrate) if datecode>30286  // extrapolate income using gr rate after Dec 1982
	replace avgearn=incseries

	sum avgearn
 
	generate admitspercap=100000*totaladmissions/pop
	drop provrate incseries

*
*	Generate lags
*
generate lagadmits=admitspercap[_n-1]
	replace lagadmits=-9999 if datecode==27030
generate lagstays=stays[_n-1]
	replace lagstays=-9999 if datecode==27030
generate lagco=co[_n-1]
	replace lagco=-9999 if datecode==27030
generate lagtsp=tsp[_n-1]
	replace lagtsp=-9999 if datecode==27030
generate lagnox=nox[_n-1]
	replace lagnox=-9999 if datecode==27030
generate lagso2=so2[_n-1]
	replace lagso2=-9999 if datecode==27030
generate lago3=o3[_n-1]
	replace lago3=-9999 if datecode==27030
generate lagpressure=pressure[_n-1]
	replace lagpressure=-9999 if datecode==27030
generate lagwindspeed=windspeed[_n-1]
	replace lagwindspeed=-9999 if datecode==27030
generate lagmeantemp=meantemp[_n-1]
	replace lagmeantemp=-9999 if datecode==27030
generate lagmintemp=mintemp[_n-1]
	replace lagmintemp=-9999 if datecode==27030
generate lagmaxtemp=maxtemp[_n-1]
	replace lagmaxtemp=-9999 if datecode==27030

mvdecode _all , mv(-9999)    // convert -9999 to "."

*
*		Time Trend 
*
generate timetrend=datecode/10000


	capture save "pwsealp.dta", replace

sum
outsheet using airhealth.csv, comma noq replace		// generate data set for BMA

*******************************************************************************
*
*		Admissions and Income Graph
*
*******************************************************************************

rename admitspercap admits
rename avgearn inc

keep inc admits datecode city year

reshape wide @admits @inc, i(datecode) j(city) string
collapse Calgaryadmits Toronto1admits Montreal1admits Calgaryinc Toronto1inc Montreal1inc, by(year)
list Calgaryadmits Toronto1admits Montreal1admits Calgaryinc Toronto1inc Montreal1inc in 1/1

generate Calgary_admissions= Calgaryadmits*100/24.6523
generate Toronto_admissions= Toronto1admits*100/30.517
generate Montreal_admissions= Montreal1admits*100/15.2205
generate Calgary_income= Calgaryinc*100/33643
generate Toronto_income= Toronto1inc*100/35643.3333
generate Montreal_income= Montreal1inc*100/32861.58333


twoway line Calgary_admissions Toronto_admissions Montreal_admissions year || ///
	scatter Calgary_income Toronto_income Montreal_income year , ///
	xlabel(#4) ytitle("Admissions, Real Income") xtitle("Year") scheme(sj) ///
	legend(cols(2) order (1 4 2 5 3 6)) xlabel( ,angle(45)) msymbol(O Dh T) mcolor(gs0 gs1 gs2)
graph save admits , replace
gr export Figure2.eps ,replace

clear
use pwsealp.dta

*******************************************************************************
*
*		Pollution by City: TABLE 2
*
*******************************************************************************

table city , c(mean co  max co  mean tsp max tsp) f(%7.2f) 
table city , c(mean so2 max so2 mean o3  max o3 ) f(%7.2f)
table city , c(mean nox max nox mean pop max pop) f(%7.2f)
table city , c(mean admitspercap max admitspercap mean stays max stays) f(%7.2f)


*******************************************************************************
*
*		PATTERNS OF MISSING DATA
*
*******************************************************************************

generate comiss=(co==.)
generate tspmiss=(tsp==.)
generate so2miss=(so2==.)
generate noxmiss=(nox==.)
generate o3miss=(o3==.)

bysort city: sum co tsp so2 nox o3 comiss tspmiss so2miss noxmiss o3miss


*******************************************************************************
*
*		REGRESSIONS
*
*******************************************************************************

*		
*		Make city dummy variables
*
tabulate city, generate(place)
describe


*
*		Convert data to z-scores
*
 drop if admitspercap<5

*
*		TABLE 1
*
sum co tsp so2 nox o3 pressure windspeed meantemperature maxtemp mintemp smokers avgearn realgdp admitspercap


egen zadm=std(admitspercap)
egen zstay=std(stays)
egen zco=std(co)
egen ztsp=std(tsp)
egen zso2=std(so2)
egen znox=std(nox)
egen zo3=std(o3)
egen zpressure=std(pressure)
egen zwindspeed=std(windspeed)
egen ztemp=std(meantemperature)
egen zsmoker=std(smokers)
egen zearn=std(avgearn)
egen zrealgdp=std(realgdp)
egen zmaxtemp=std(maxtemp)
egen zmintemp=std(mintemp)

*
*		Show influence of clustering by province
*
reg zadm zco ztsp zso2 znox zo3 zpressure zwindspeed ztemp zsmoker zearn zrealgdp
	est store BasicOLS

reg zadm zco ztsp zso2 znox zo3 zpressure zwindspeed ztemp zsmoker zearn zrealgdp, robust cluster(pop)
	est store Cluster
*
*		Show influence of adding city/month dummies
*
reg zadm zco ztsp zso2 znox zo3 zpressure zwindspeed ztemp zsmoker zearn zrealgdp mon1-mon11 place1-place10, robust cluster(pop)
	est store CityMonth

*
*		Show influence of adding time trend
*
reg zadm timetrend zco ztsp zso2 znox zo3 zpressure zwindspeed ztemp zsmoker zearn zrealgdp mon1-mon11 place1-place10, robust cluster(pop)
	est store TimeTrend

*
*		Show influence of cherry-picking
*
reg zadm zco zpressure zwindspeed ztemp zsmoker if year>1984, robust cluster(pop)
reg zadm zco zso2 znox ztsp zo3 zpressure zwindspeed ztemp zsmoker if year>1984, robust cluster(pop)


*
*		TABLE 3
*
est table BasicOLS Cluster CityMonth TimeTrend , t(%5.2f) b(%7.3f) stfmt(%9.2f) stats(N r2 ll bic) style(columns)

*******************************************************************************
*
*		GRAPHS
*
*******************************************************************************

clear
insheet using pollution.and.weather.csv
drop if year>1994
keep co datecode year city

//                 CO
reshape wide @co, i(datecode) j(city) string

rename Toronto1co Toronto_co
rename Montreal1co Montreal_co
rename Calgaryco Calgary_co

twoway scatter Calgary_co Toronto_co Montreal_co year , xlabel(#4) ytitle("CO Levels in ppm") ///
	xtitle("Date") scheme(sj) legend(cols(3) position(12)) xlabel( ,angle(45))
graph save co , replace

//                 TSP
clear
insheet using pollution.and.weather.csv
drop if year>1994
keep tsp datecode year city
reshape wide @tsp, i(datecode) j(city) string

rename Toronto1tsp Toronto_tsp
rename Montreal1tsp Montreal_tsp
rename Calgarytsp Calgary_tsp

twoway scatter Calgary_tsp Toronto_tsp Montreal_tsp year , xlabel(#4) ytitle("TSP Levels in ug/m3") xtitle("Date") ///
 	scheme(sj) legend(cols(1) position(3)) xlabel( ,angle(45))
graph save tsp , replace

//                 O3
clear
insheet using pollution.and.weather.csv
drop if year>1994
keep o3 datecode year city
reshape wide @o3, i(datecode) j(city) string

rename Toronto1o3 Toronto_o3
rename Montreal1o3 Montreal_o3
rename Calgaryo3 Calgary_o3

twoway scatter Calgary_o3 Toronto_o3 Montreal_o3 year, xlabel(#4) ytitle("O3 Levels in ppb") xtitle("Date")  ///
	scheme(sj) legend(cols(3) position(12)) xlabel( ,angle(45))
graph save o3 , replace

//                 SO2
clear
insheet using pollution.and.weather.csv
drop if year>1994
keep so2 datecode year city
reshape wide @so2, i(datecode) j(city) string

rename Toronto1so2 Toronto_so2
rename Montreal1so2 Montreal_so2
rename Calgaryso2 Calgary_so2

twoway scatter Calgary_so2 Toronto_so2 Montreal_so2 year , ///
	xlabel(#4) ytitle("SO2 Levels in ppb") xtitle("Date") ///
	scheme(sj) title(,margin(right)) xlabel( ,angle(45)) legend(cols(3) position(12))
graph save so2 , replace

graph combine so2.gph co.gph, c(1) saving(airpoll, replace) scheme(sj) 

gr export Figure1.eps ,replace




exit


